require_relative "./base"

class Pex2SystemTest < LifePexTest
  def setup
    @fixture ||= FixtureReader.new # should be in startup
    @fixture.apply! "user_base"
  end

  def cleanup
    @fixture.cleanup!
  end

  private def login_as(username = "test", password = "test")
    api_post '/api/user/v1/login', { username: username, password: password }
  end

  def test_pex_life_cycle
    login_as
    assert last_response.ok?

    api_get "/api/pex/v2/pexs"
    assert last_response.ok?
    assert_empty api_reponse_body

    pex_input = { name: "pex1", category: "cat1", amount: 1.23 }
    api_post "/api/pex/v2/pexs", pex_input
    assert last_response.ok?, "A new pex should have been added"
    assert_message_exist
    assert_hash_include pex_input, api_reponse_body["pex"]
    assert_entity_owned api_reponse_body["pex"]
    pex_id = api_reponse_body.dig "pex", "id"

    api_get "/api/pex/v2/pexs"
    assert last_response.ok?
    assert_equal 1, api_reponse_body.size, "A new pex should exist"

    api_get "/api/pex/v2/pexs/#{pex_id}"
    assert last_response.ok?
    assert_hash_include pex_input, api_reponse_body["pex"]
    assert_entity_owned api_reponse_body["pex"]

    api_get "/api/pex/v2/pexs/#{pex_id}/more"
    assert last_response.ok?
    assert_hash_include pex_input, api_reponse_body["pex"]
    assert_entity_owned api_reponse_body["pex"]
  end
end
